@@ -15,17 +15,17 @@
 var program = require('commander');
 
 function app_init(){
-  var init=require('./lib/init');
+  var init=require('./lib/bin/init');
   init.create(__dirname);
 }
 
 function app_server(){
-  var server=require('./lib/server');
+  var server=require('./lib/bin/server');
   server.serve(__dirname);
 }
 
 program
-  .version('1.0.4')
+  .version('1.2.0')
   .option('-i, init', 'init project',app_init)
   .option('-s, serve', 'start nylon server',app_server)
   .parse(process.argv);
