@@ -5,35 +5,36 @@
  */
 package nylon.report;
 
+import com.fasterxml.jackson.core.type.TypeReference;
+import com.fasterxml.jackson.databind.ObjectMapper;
+import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.FileInputStream;
-import java.io.FileNotFoundException;
-import java.io.InputStream;
-import java.lang.reflect.Field;
-import java.util.ArrayList;
+import java.io.IOException;
 import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRException;
-import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperFillManager;
 import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.JasperReport;
-import net.sf.jasperreports.engine.data.JRMapCollectionDataSource;
+import net.sf.jasperreports.engine.data.JsonDataSource;
 import net.sf.jasperreports.engine.export.JRPdfExporter;
-import net.sf.jasperreports.engine.export.JRXlsExporter;
-import net.sf.jasperreports.engine.export.JRXlsExporterParameter;
+import net.sf.jasperreports.engine.export.HtmlExporter;
+import net.sf.jasperreports.engine.export.JRXml4SwfExporter;
+import net.sf.jasperreports.engine.export.JRCsvExporter;
 import net.sf.jasperreports.engine.export.ooxml.JRDocxExporter;
 import net.sf.jasperreports.engine.export.ooxml.JRXlsxExporter;
 import net.sf.jasperreports.engine.util.JRLoader;
-import org.codehaus.jettison.json.JSONArray;
-import org.codehaus.jettison.json.JSONException;
-import org.codehaus.jettison.json.JSONObject;
+import net.sf.jasperreports.export.Exporter;
+import net.sf.jasperreports.export.SimpleExporterInput;
+import net.sf.jasperreports.export.SimpleHtmlExporterOutput;
+import net.sf.jasperreports.export.SimpleOutputStreamExporterOutput;
+import net.sf.jasperreports.export.SimpleWriterExporterOutput;
+import net.sf.jasperreports.export.SimpleXmlExporterOutput;
 
 /**
  *
@@ -41,25 +42,118 @@ import org.codehaus.jettison.json.JSONObject;
  */
 public class iReport {
 
-    public enum ExportMode {
+    public iReport() {
+      
+    }
+
+    public String export(String reportFile, String exportMode, String datas, String parameters) {
+        try {
+            Exporter exporter;
+            JasperPrint jpPrint = this.jrPrint(reportFile, datas.getBytes("UTF-8"), parameters.getBytes("UTF-8"));
+            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+            switch (exportMode.toLowerCase()) {
+                case "pdf":
+                    exporter = new JRPdfExporter();
+                    exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(outputStream));
+                    break;
+                case "excel":
+                    exporter = new JRXlsxExporter();
+                    exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(outputStream));
+                    break;
+                case "word":
+                    exporter = new JRDocxExporter();
+                    exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(outputStream));
+                    break;
+                case "csv":
+                    exporter = new JRCsvExporter();
+                    exporter.setExporterOutput(new SimpleWriterExporterOutput(outputStream));
+                    break;
+                case "html":
+                    exporter = new HtmlExporter();
+                    exporter.setExporterOutput(new SimpleHtmlExporterOutput(outputStream));
+                    break;
+                case "xml":
+                    exporter = new JRXml4SwfExporter();
+                    exporter.setExporterOutput(new SimpleXmlExporterOutput(outputStream));
+                    break;
+                default:
+                    exporter = new JRPdfExporter();
+                    exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(outputStream));
+                    break;
+            }
+
+            exporter.setExporterInput(new SimpleExporterInput(jpPrint));
+            //exporter.setExporterOutput(new SimpleOutputStreamExporterOutput(outputStream));
+
+            exporter.exportReport();
+            byte[] out = outputStream.toByteArray();
+            return byteArrayToHex(out);
+        } catch (JRException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
+
+        } catch (IOException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
+        }
+        return byteArrayToHex(new byte[]{});
+    }
+
+    private JasperPrint jrPrint(String reportFile, byte[] datas, byte[] parameter) throws IOException {
+        JasperReport jpReport;
+        JRDataSource jpData;
+        Map<String, Object> jpParam;
+        try {
+            FileInputStream reportStream = new FileInputStream(reportFile);
+            jpData = new JsonDataSource(new ByteArrayInputStream(datas));
+            jpParam = this.getParameter(parameter);
+            if (reportFile.endsWith(".jrxml")) {
+                jpReport = JasperCompileManager.compileReport(reportStream);
+            } else {
+                jpReport = (JasperReport) JRLoader.loadObject(reportStream);
+            }
+            JasperPrint jpPrint = JasperFillManager.fillReport(jpReport, jpParam, jpData);
+            return jpPrint;
+        } catch (JRException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
+        }
+        return null;
+    }
+
+    private Map<String, Object> getParameter(byte[] parameter) throws IOException {
+        ObjectMapper objectMapper = new ObjectMapper();
+        HashMap<String, Object> pms = objectMapper.readValue(
+                new ByteArrayInputStream(parameter),
+                new TypeReference<HashMap<String, Object>>() {
+        }
+        );
+        return pms;
+       // byte[] a;
+      // Hex.encodeHexString( bytes ) 
+    }
+    
+    public String byteArrayToHex(byte[] a) {
+        StringBuilder sb = new StringBuilder(a.length * 2);
+        for (byte b : a) {
+            sb.append(String.format("%02x", b & 0xff));
+        }
+        return sb.toString();
+    }
+
+    /* public enum ExportMode {
         PDF,
         EXCEL,
-        WORD
-    }
-
-    private InputStream ReportJrxml;
-    private String ReportJrxmlName;
-    private JasperPrint jpPrint;
-    private Object reportData;
-    private Object parameter;
-    private ExportMode exportMode = ExportMode.PDF;
-
-    public iReport() {
-        // parameters = new HashMap<>();
-    }
-
-    public String export(String reportName, String type, Object data, Object parameter) {
-        System.out.println(System.getProperty("user.dir"));
+        WORD,
+        CSV,
+        HTML,
+        XML
+    }*/
+    //private InputStream ReportJrxml;
+    //private String ReportJrxmlName;
+    // private JasperPrint jpPrint;
+    // private Object reportData;
+    // private Object parameter;
+    // private ExportMode exportMode = ExportMode.PDF;
+    /* public byte[] export(String reportName, String type, byte[] data, byte[] parameter) {
+        //System.out.println(System.getProperty("user.dir"));
         if (null == type.toLowerCase()) {
             exportMode = ExportMode.PDF;
         } else //  parameters = new HashMap<>();
@@ -74,6 +168,15 @@ public class iReport {
                 case "excel":
                     exportMode = ExportMode.EXCEL;
                     break;
+                case "csv":
+                    exportMode = ExportMode.CSV;
+                    break;
+                case "html":
+                    exportMode = ExportMode.HTML;
+                    break;
+                case "xml":
+                    exportMode = ExportMode.XML;
+                    break;
                 default:
                     exportMode = ExportMode.PDF;
                     break;
@@ -83,21 +186,25 @@ public class iReport {
         this.reportData = data;
         this.parameter = parameter;
 
-        return byteArrayToHex(this.exporter());
-    }
+        try {
+            return byteArrayToHex(this.exporter());
+        } catch (IOException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
+        }
+        return null;
+    }*/
 
-    public String byteArrayToHex(byte[] a) {
+ /*public String byteArrayToHex(byte[] a) {
         StringBuilder sb = new StringBuilder(a.length * 2);
         for (byte b : a) {
             sb.append(String.format("%02x", b & 0xff));
         }
         return sb.toString();
-    }
+    }*/
 //    public Map<String, Object> getParameter() {
 //        return parameters;
 //    }
-
-    private Map<String, Object> getParameter() {
+    /*private Map<String, Object> getParameter() throws IOException {
         if (this.parameter.getClass() == String.class) {
             return this.getParameterFromJSON();
         } else {
@@ -130,27 +237,33 @@ public class iReport {
 
     }
 
-    private Map<String, Object> getParameterFromJSON() {
-        Map<String, Object> pms = new HashMap<>();
+    private Map<String, Object> getParameterFromJSON() throws IOException {
+        // ObjectMapper objectMapper = new ObjectMapper();
+        ObjectMapper objectMapper = new ObjectMapper();
+        HashMap<String, Object> pms = objectMapper.readValue(this.parameter.toString(), new TypeReference<HashMap<String, Object>>() {
+        });
+        // Map<String, Object> pms = new HashMap<>();
+        return pms;
+
+        /* Map<String, Object> pms = new HashMap<>();
         JSONObject pm = null;
         try {
             pm = new JSONObject(parameter.toString());
-            pms=this.getObjectJSON(pm);
-           // Iterator e = pm.keys();
+            pms = this.getObjectJSON(pm);
+            // Iterator e = pm.keys();
             //while (e.hasNext()) {
-             //   String name = (String) e.next();
-              //  try {
-               //     pms.put(name, pm.get(name));
-               // } catch (JSONException ex) {
-                 //   Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
-               // }
+            //   String name = (String) e.next();
+            //  try {
+            //     pms.put(name, pm.get(name));
+            // } catch (JSONException ex) {
+            //   Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
+            // }
             //}
         } catch (JSONException ex) {
             Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
         }
-        return pms;
-    }
-
+        return pms;*/
+    // }
 //    public void setParameter(Map<String, Object> parameters) {
 //        this.parameters = parameters;
 //    }
@@ -181,7 +294,7 @@ public class iReport {
 //    public void setReport(InputStream ReportJrxml) {
 //        this.ReportJrxml = ReportJrxml;
 //    }
-    private void getReport() {
+    /*private void getReport() throws IOException {
         try {
             this.ReportJrxml = new FileInputStream(this.ReportJrxmlName);
         } catch (FileNotFoundException ex) {
@@ -192,9 +305,9 @@ public class iReport {
         } else {
             this.getReportJASPER();
         }
-    }
+    }*/
 
-    private void getReportJASPER() {
+ /*private void getReportJASPER() {
         JasperReport jpReport;
 
         JRDataSource jpData;
@@ -208,46 +321,12 @@ public class iReport {
         } catch (Exception ex) {
             Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
         }
-    }
-
-    private void getReportJRXML() {
-        JasperReport jpReport;
-        JRDataSource jpData;
-        Map<String, Object> jpParam;
-        try {
-            jpData = this.getDataCollection();
-            jpParam = this.getParameter();
-            jpReport = JasperCompileManager.compileReport(this.ReportJrxml);
-            jpPrint = JasperFillManager.fillReport(jpReport, jpParam, jpData);
-        } catch (JRException ex) {
-            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
-        }
-    }
-
+    }*/
 //    public Object Export(Class _assembly, String CurrentPaht) {
 //        this.ReportJrxml = _assembly.getResourceAsStream(this.ReportJrxmlName);
 //        return this.Export();
 //    }
-    private byte[] exporter() {
-        byte[] output;
-        switch (this.exportMode) {
-            case PDF:
-                output = exportToPdf();
-                break;
-            case EXCEL:
-                output = exportToExcel();
-                break;
-            case WORD:
-                output = exportToWord();
-                break;
-            default:
-                output = exportToPdf();
-                break;
-        }
-        return output;
-    }
-
-    private byte[] exportToPdf() {
+    /* private byte[] exportToPdf() {
 
         try {
             if (this.jpPrint == null) {
@@ -266,9 +345,83 @@ public class iReport {
             Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
             return null;
         }
-    }
+    }*/
 
-    private byte[] exportToExcel() {
+ /*  private byte[] exportToCsv() {
+
+        try {
+            if (this.jpPrint == null) {
+                this.getReport();
+            }
+            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+            JRCsvExporter exporter = null;
+            exporter = new JRCsvExporter();
+            exporter.setParameter(JRExporterParameter.JASPER_PRINT, jpPrint);
+            exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, outputStream);
+            exporter.exportReport();
+            byte[] out = outputStream.toByteArray();
+            return out;
+
+        } catch (JRException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
+            return null;
+        }
+    }*/
+
+ /* private byte[] exportToHtml() {
+
+        try {
+            if (this.jpPrint == null) {
+                this.getReport();
+            }
+            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+            JRHtmlExporter exporter = null;
+            exporter = new JRHtmlExporter();
+
+            // HtmlReportConfiguration reportExportConfiguration = new SimpleHtmlReportConfiguration();
+            //   reportExportConfiguration..set.setWhitePageBackground(true);
+            //  reportExportConfiguration.setRemoveEmptySpaceBetweenRows(true);
+            //  reportExportConfiguration.setEmbeddedSvgUseFonts(Boolean.TRUE);
+            //  reportExportConfiguration.setEmbedImage(Boolean.TRUE);
+            // reportExportConfiguration.set
+            exporter.setParameter(JRExporterParameter.JASPER_PRINT, jpPrint);
+            exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, outputStream);
+            exporter.setParameter(JRHtmlExporterParameter.CHARACTER_ENCODING, "UTF-8");
+            // exporter.setConfiguration(reportExportConfiguration);
+            exporter.setParameter(JRHtmlExporterParameter., new HashMap());
+            exporter.setParameter(JRHtmlExporterParameter.IMAGES_URI, "image?image=");
+            exporter.exportReport();
+            byte[] out = outputStream.toByteArray();
+            return out;
+
+        } catch (JRException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
+            return null;
+        }
+    }*/
+
+ /* private byte[] exportToXml() {
+
+        try {
+            if (this.jpPrint == null) {
+                this.getReport();
+            }
+            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+            JRXml4SwfExporter exporter = null;
+            exporter = new JRXml4SwfExporter();
+            exporter.setParameter(JRExporterParameter.JASPER_PRINT, jpPrint);
+            exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, outputStream);
+            exporter.exportReport();
+            byte[] out = outputStream.toByteArray();
+            return out;
+
+        } catch (JRException ex) {
+            Logger.getLogger(iReport.class.getName()).log(Level.WARNING, ex.getMessage(), ex);
+            return null;
+        }
+    }*/
+
+ /*  private byte[] exportToExcel() {
         {
             try {
                 if (this.jpPrint == null) {
@@ -292,9 +445,9 @@ public class iReport {
             }
         }
         return null;
-    }
+    }*/
 
-    private byte[] exportToWord() {
+ /* private byte[] exportToWord() {
         {
             try {
                 if (this.jpPrint == null) {
@@ -318,17 +471,16 @@ public class iReport {
             }
         }
         return null;
-    }
+    }*/
+    // private List getData() throws IOException {
+    //   if (this.reportData.getClass() == String.class) {
+    //   return this.getDataFromJson();
+    //   } else {
+    //    return this.getDataFromArray();
+    // }
+    // }
 
-    private List getData() {
-        if (this.reportData.getClass() == String.class) {
-            return this.getDateFromJson();
-        } else {
-            return this.getDataFromArray();
-        }
-    }
-
-    private List getDataFromArray() {
+    /*private List getDataFromArray() {
         List listdata = new ArrayList();
         List<?> data = (List<?>) this.reportData;
         data.stream().map((reportData1) -> {
@@ -357,24 +509,32 @@ public class iReport {
             listdata.add(pmap);
         });
         return listdata;
-    }
+    }*/
+    //private List getDataFromJson() throws IOException {
+    //  ObjectMapper objectMapper = new ObjectMapper();
+    // ObjectMapper objectMapper = new ObjectMapper();
+    // List<HashMap<String, Object>> listdata = objectMapper.readValue(this.reportData.toString(), new TypeReference<List<HashMap<String, Object>>>() {
+    // });
+    //objectMapper.
+    //  return listdata;
 
-    private List getDateFromJson() {
-        List listdata = new ArrayList();
+    /*  List listdata = new ArrayList();
         if (null != this.reportData) {
+            HashMap<String,Object> d = objectMapper.readValue(this.reportData.toString(),new TypeReference<HashMap<String,Object>>() {});
+            
             JSONArray d = null;
             try {
                 d = new JSONArray(this.reportData.toString());
-                listdata=this.getObjectJSONArray(d);
+                listdata = this.getObjectJSONArray(d);
             } catch (JSONException ex) {
                 Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
             }
 
         }
-        return listdata;
-    }
+        return listdata;*/
+    // }
 
-    private List getObjectJSONArray(JSONArray d) {
+    /* private List getObjectJSONArray(JSONArray d) {
         List listdata = new ArrayList();
         for (int i = 0; i < d.length(); i++) {
             try {
@@ -382,8 +542,8 @@ public class iReport {
                 if (dd.getClass() == JSONObject.class) {
                     Map<String, Object> obj = this.getObjectJSON((JSONObject) dd);
                     listdata.add(obj);
-                }else{
-                   // Object obj=d.get(i);
+                } else {
+                    // Object obj=d.get(i);
                     Map<String, Object> obj = new HashMap<>();
                     obj.put("index", dd);
                     listdata.add(obj);
@@ -394,34 +554,41 @@ public class iReport {
         }
 
         return listdata;
-    }
+    }*/
 
-    private Map<String, Object> getObjectJSON(JSONObject dd) {
+ /* private Map<String, Object> getObjectJSON(JSONObject dd) {
         Iterator e = dd.keys();
         Map<String, Object> obj = new HashMap<>();
         while (e.hasNext()) {
             String name = (String) e.next();
             try {
-             //   System.out.println(name);
-                 Object v =dd.get(name);
-                 if (v.getClass() == JSONObject.class) {
-                     obj.put(name, this.getObjectJSON((JSONObject) v));
-                 }else if(v.getClass()==JSONArray.class){
-                      obj.put(name, this.getObjectJSONArray((JSONArray) v));
-                 }else{
+                //   System.out.println(name);
+                Object v = dd.get(name);
+                if (v.getClass() == JSONObject.class) {
+                    obj.put(name, this.getObjectJSON((JSONObject) v));
+                } else if (v.getClass() == JSONArray.class) {
+                    obj.put(name, this.getObjectJSONArray((JSONArray) v));
+                } else {
                     obj.put(name, v);
-                 }
-                
+                }
+
             } catch (JSONException ex) {
                 Logger.getLogger(iReport.class.getName()).log(Level.SEVERE, null, ex);
             }
         }
         return obj;
-    }
-
-    private JRMapCollectionDataSource getDataCollection() {
-        JRMapCollectionDataSource datas = new JRMapCollectionDataSource(this.getData());
-      //  net.sf.jasperreports.engine.data.JRBeanArrayDataSource
-        return datas;
-    }
+    }*/
+ /* private JsonDataSource getDataCollection() throws  JRException, UnsupportedEncodingException {
+        //JRMapCollectionDataSource datas = new JRMapCollectionDataSource(this.getData());
+        //  net.sf.jasperreports.engine.data.JRBeanArrayDataSource
+        InputStream is = new ByteArrayInputStream(this.reportData.toString().getBytes("UTF-8"));
+        JsonDataSource jsonds =new JsonDataSource(is);
+    //    JsonDataCollection js=new JsonDataCollection<>()
+        //jsonds.
+     //new JsonNode();
+    // ObjectMapper objectMapper = new ObjectMapper();
+   //  JsonNode x;
+   //  x.binaryValue()
+        return jsonds;
+    }*/
 }
