@@ -1,6 +1,7 @@
 var passport=require('passport');
 var LocalStrategy=require('passport-local').Strategy;
-module.exports=function(config){    
+const config=require(process.cwd()+'/config/config');
+module.exports=function(){    
      passport.use(new LocalStrategy(
         function(username,password,done){
             console.log('LocalStrategy');
